@@ -36,19 +36,19 @@ function (x = world.cities, country = "", label = NULL, minpop = 0,
     }
     usr <- par("usr")
     if (!missing(projection) && projection != FALSE) {
-	require(mapproj)
-        if (is.character(projection)) {
-	    projx <- mapproject(x$long, x$lat, projection = projection,
-	        parameters = parameters, orientation = orientation)
-	} else {
-            if (exists(".Last.projection")) {
-	        projx <- mapproject(x$long, x$lat)
-	    } else stop("No projection defined\n")
-        }
-	x$long <- projx$x
-	x$lat <- projx$y
+	if (require(mapproj)) {
+            if (is.character(projection)) {
+	        projx <- mapproject(x$long, x$lat, projection = projection,
+	            parameters = parameters, orientation = orientation)
+	    } else {
+                if (nchar(.Last.projection()$projection) > 0) {
+	            projx <- mapproject(x$long, x$lat)
+	        } else stop("No projection defined\n")
+            }
+	    x$long <- projx$x
+	    x$lat <- projx$y
+	} else stop("mapproj package not available\n")
     } else {
-	mapproject <- function() {}	# Keep R CMD check quiet
 	if (usr[2] > (180 + 0.04*(usr[2] - usr[1]))) 
 	    x$long[x$long < 0] <- 360 + x$long[x$long < 0]
     }
